==> vertx-rx-java-gen-3.9.2.redhat-00001-test-sources.jar: io/vertx/rxjava/codegen/extra/UseVertxGenDeclarationsFromAnotherPackage.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.rxjava.codegen.extra;

import rx.Observable;
import rx.Single;
import io.vertx.rx.java.RxHelper;
import io.vertx.rx.java.WriteStreamSubscriber;
import io.vertx.rx.java.SingleOnSubscribeAdapter;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage.class)
public class UseVertxGenDeclarationsFromAnotherPackage extends io.vertx.rxjava.codegen.extra.sub.SomeType implements io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType>, Handler<io.vertx.rxjava.codegen.extra.sub.SomeType> {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UseVertxGenDeclarationsFromAnotherPackage that = (UseVertxGenDeclarationsFromAnotherPackage) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<UseVertxGenDeclarationsFromAnotherPackage> __TYPE_ARG = new TypeArg<>(    obj -> new UseVertxGenDeclarationsFromAnotherPackage((io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage) obj),
    UseVertxGenDeclarationsFromAnotherPackage::getDelegate
  );

  private final io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage delegate;
  
  public UseVertxGenDeclarationsFromAnotherPackage(io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage delegate) {
    super(delegate);
    this.delegate = delegate;
  }

  public UseVertxGenDeclarationsFromAnotherPackage(Object delegate) {
    super((io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage)delegate);
    this.delegate = (io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage)delegate;
  }

  public io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage getDelegate() {
    return delegate;
  }

  private Observable<io.vertx.rxjava.codegen.extra.sub.SomeType> observable;

  public synchronized Observable<io.vertx.rxjava.codegen.extra.sub.SomeType> toObservable() {
    if (observable == null) {
      Function<io.vertx.codegen.extra.sub.SomeType, io.vertx.rxjava.codegen.extra.sub.SomeType> conv = io.vertx.rxjava.codegen.extra.sub.SomeType::newInstance;
      observable = RxHelper.toObservable(delegate, conv);
    }
    return observable;
  }

  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_0 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_1 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_2 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_3 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_4 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_5 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_6 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_7 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());

  public void handle(io.vertx.rxjava.codegen.extra.sub.SomeType arg0) { 
    delegate.handle(arg0.getDelegate());
  }

  /**
   * Set an exception handler on the read stream.
   * @param handler the exception handler
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> exceptionHandler(Handler<java.lang.Throwable> handler) { 
    delegate.exceptionHandler(handler);
    return this;
  }

  /**
   * Set a data handler. As data is read, the handler will be called with the data.
   * @param handler 
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> handler(Handler<io.vertx.rxjava.codegen.extra.sub.SomeType> handler) { 
    delegate.handler(new Handler<io.vertx.codegen.extra.sub.SomeType>() {
      public void handle(io.vertx.codegen.extra.sub.SomeType event) {
        handler.handle(io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)event));
      }
    });
    return this;
  }

  /**
   * Pause the <code>ReadStream</code>, it sets the buffer in <code>fetch</code> mode and clears the actual demand.
   * <p>
   * While it's paused, no data will be sent to the data <code>handler</code>.
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> pause() { 
    delegate.pause();
    return this;
  }

  /**
   * Resume reading, and sets the buffer in <code>flowing</code> mode.
   * <p/>
   * If the <code>ReadStream</code> has been paused, reading will recommence on it.
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> resume() { 
    delegate.resume();
    return this;
  }

  /**
   * Fetch the specified <code>amount</code> of elements. If the <code>ReadStream</code> has been paused, reading will
   * recommence with the specified <code>amount</code> of items, otherwise the specified <code>amount</code> will
   * be added to the current stream demand.
   * @param amount 
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> fetch(long amount) { 
    delegate.fetch(amount);
    return this;
  }

  /**
   * Set an end handler. Once the stream has ended, and there is no more data to be read, this handler will be called.
   * @param endHandler 
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> endHandler(Handler<Void> endHandler) { 
    delegate.endHandler(endHandler);
    return this;
  }

  /**
   * Pause this stream and return a  to transfer the elements of this stream to a destination .
   * <p/>
   * The stream will be resumed when the pipe will be wired to a <code>WriteStream</code>.
   * @return a pipe
   */
  public io.vertx.rxjava.core.streams.Pipe<io.vertx.rxjava.codegen.extra.sub.SomeType> pipe() { 
    io.vertx.rxjava.core.streams.Pipe<io.vertx.rxjava.codegen.extra.sub.SomeType> ret = io.vertx.rxjava.core.streams.Pipe.newInstance((io.vertx.core.streams.Pipe)delegate.pipe(), TYPE_ARG_6);
    return ret;
  }

  /**
   * Like {@link io.vertx.rxjava.core.streams.ReadStream#pipeTo} but with no completion handler.
   * @param dst 
   */
  public void pipeTo(io.vertx.rxjava.core.streams.WriteStream<io.vertx.rxjava.codegen.extra.sub.SomeType> dst) { 
    delegate.pipeTo(dst.getDelegate());
  }

  /**
   * Pipe this <code>ReadStream</code> to the <code>WriteStream</code>.
   * <p>
   * Elements emitted by this stream will be written to the write stream until this stream ends or fails.
   * <p>
   * Once this stream has ended or failed, the write stream will be ended and the <code>handler</code> will be
   * called with the result.
   * @param dst the destination write stream
   * @param handler 
   */
  public void pipeTo(io.vertx.rxjava.core.streams.WriteStream<io.vertx.rxjava.codegen.extra.sub.SomeType> dst, Handler<AsyncResult<Void>> handler) { 
    delegate.pipeTo(dst.getDelegate(), handler);
  }

    /**
   * Pipe this <code>ReadStream</code> to the <code>WriteStream</code>.
   * <p>
   * Elements emitted by this stream will be written to the write stream until this stream ends or fails.
   * <p>
   * Once this stream has ended or failed, the write stream will be ended and the <code>handler</code> will be
   * called with the result.
   * @param dst the destination write stream
   * @return 
   * @deprecated use {@link #rxPipeTo} instead
   */
  @Deprecated()
  public Observable<Void> pipeToObservable(io.vertx.rxjava.core.streams.WriteStream<io.vertx.rxjava.codegen.extra.sub.SomeType> dst) { 
    io.vertx.rx.java.ObservableFuture<Void> handler = io.vertx.rx.java.RxHelper.observableFuture();
    pipeTo(dst, handler.toHandler());
    return handler;
  }

  /**
   * Pipe this <code>ReadStream</code> to the <code>WriteStream</code>.
   * <p>
   * Elements emitted by this stream will be written to the write stream until this stream ends or fails.
   * <p>
   * Once this stream has ended or failed, the write stream will be ended and the <code>handler</code> will be
   * called with the result.
   * @param dst the destination write stream
   * @return 
   */
  public Single<Void> rxPipeTo(io.vertx.rxjava.core.streams.WriteStream<io.vertx.rxjava.codegen.extra.sub.SomeType> dst) { 
    return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
      pipeTo(dst, fut);
    }));
  }

  public io.vertx.rxjava.codegen.extra.sub.SomeType foo(io.vertx.rxjava.codegen.extra.sub.SomeType arg) { 
    if (cached_0 != null) {
      return cached_0;
    }
    io.vertx.rxjava.codegen.extra.sub.SomeType ret = io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)delegate.foo(arg.getDelegate()));
    cached_0 = ret;
    return ret;
  }

  public void function(Function<io.vertx.rxjava.codegen.extra.sub.SomeType, io.vertx.rxjava.codegen.extra.sub.SomeType> function) { 
    delegate.function(new Function<io.vertx.codegen.extra.sub.SomeType,io.vertx.codegen.extra.sub.SomeType>() {
      public io.vertx.codegen.extra.sub.SomeType apply(io.vertx.codegen.extra.sub.SomeType arg) {
        io.vertx.rxjava.codegen.extra.sub.SomeType ret = function.apply(io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)arg));
        return ret.getDelegate();
      }
    });
  }

  public void asyncResult(Handler<AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType>> handler) { 
    delegate.asyncResult(new Handler<AsyncResult<io.vertx.codegen.extra.sub.SomeType>>() {
      public void handle(AsyncResult<io.vertx.codegen.extra.sub.SomeType> ar) {
        if (ar.succeeded()) {
          handler.handle(io.vertx.core.Future.succeededFuture(io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)ar.result())));
        } else {
          handler.handle(io.vertx.core.Future.failedFuture(ar.cause()));
        }
      }
    });
  }

    @Deprecated()
  public Observable<io.vertx.rxjava.codegen.extra.sub.SomeType> asyncResultObservable() { 
    io.vertx.rx.java.ObservableFuture<io.vertx.rxjava.codegen.extra.sub.SomeType> handler = io.vertx.rx.java.RxHelper.observableFuture();
    asyncResult(handler.toHandler());
    return handler;
  }

  public Single<io.vertx.rxjava.codegen.extra.sub.SomeType> rxAsyncResult() { 
    return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
      asyncResult(fut);
    }));
  }

  public Handler<io.vertx.rxjava.codegen.extra.sub.SomeType> returnHandler() { 
    Handler<io.vertx.rxjava.codegen.extra.sub.SomeType> ret = new Handler<io.vertx.rxjava.codegen.extra.sub.SomeType>() {
      public void handle(io.vertx.rxjava.codegen.extra.sub.SomeType event) {
          delegate.returnHandler().handle(event.getDelegate());
      }
    };
    return ret;
  }

  public Handler<AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType>> returnHandlerAsyncResult() { 
    Handler<AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType>> ret = new Handler<AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType>>() {
      public void handle(AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType> ar) {
        if (ar.succeeded()) {
          delegate.returnHandlerAsyncResult().handle(io.vertx.core.Future.succeededFuture(ar.result().getDelegate()));
        } else {
          delegate.returnHandlerAsyncResult().handle(io.vertx.core.Future.failedFuture(ar.cause()));
        }
      }
    };
    return ret;
  }

  private io.vertx.rxjava.codegen.extra.sub.SomeType cached_0;
  public static UseVertxGenDeclarationsFromAnotherPackage newInstance(io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage arg) {
    return arg != null ? new UseVertxGenDeclarationsFromAnotherPackage(arg) : null;
  }

}

==> vertx-rx-java-gen-4.0.0.redhat-00001-test-sources.jar: io/vertx/rxjava/codegen/extra/UseVertxGenDeclarationsFromAnotherPackage.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.rxjava.codegen.extra;

import rx.Observable;
import rx.Single;
import io.vertx.rx.java.RxHelper;
import io.vertx.rx.java.WriteStreamSubscriber;
import io.vertx.rx.java.SingleOnSubscribeAdapter;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage.class)
public class UseVertxGenDeclarationsFromAnotherPackage extends io.vertx.rxjava.codegen.extra.sub.SomeType implements io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType>, Handler<io.vertx.rxjava.codegen.extra.sub.SomeType> {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UseVertxGenDeclarationsFromAnotherPackage that = (UseVertxGenDeclarationsFromAnotherPackage) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<UseVertxGenDeclarationsFromAnotherPackage> __TYPE_ARG = new TypeArg<>(    obj -> new UseVertxGenDeclarationsFromAnotherPackage((io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage) obj),
    UseVertxGenDeclarationsFromAnotherPackage::getDelegate
  );

  private final io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage delegate;
  
  public UseVertxGenDeclarationsFromAnotherPackage(io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage delegate) {
    super(delegate);
    this.delegate = delegate;
  }

  public UseVertxGenDeclarationsFromAnotherPackage(Object delegate) {
    super((io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage)delegate);
    this.delegate = (io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage)delegate;
  }

  public io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage getDelegate() {
    return delegate;
  }

  private Observable<io.vertx.rxjava.codegen.extra.sub.SomeType> observable;

  public synchronized Observable<io.vertx.rxjava.codegen.extra.sub.SomeType> toObservable() {
    if (observable == null) {
      Function<io.vertx.codegen.extra.sub.SomeType, io.vertx.rxjava.codegen.extra.sub.SomeType> conv = io.vertx.rxjava.codegen.extra.sub.SomeType::newInstance;
      observable = RxHelper.toObservable(delegate, conv);
    }
    return observable;
  }

  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_0 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_1 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_2 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_3 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_4 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_5 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_6 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());
  private static final TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType> TYPE_ARG_7 = new TypeArg<io.vertx.rxjava.codegen.extra.sub.SomeType>(o1 -> io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)o1), o1 -> o1.getDelegate());

  public void handle(io.vertx.rxjava.codegen.extra.sub.SomeType arg0) { 
    delegate.handle(arg0.getDelegate());
  }

  /**
   * Set an exception handler on the read stream.
   * @param handler the exception handler
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> exceptionHandler(Handler<java.lang.Throwable> handler) { 
    delegate.exceptionHandler(handler);
    return this;
  }

  /**
   * Set a data handler. As data is read, the handler will be called with the data.
   * @param handler 
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> handler(Handler<io.vertx.rxjava.codegen.extra.sub.SomeType> handler) { 
    delegate.handler(new Handler<io.vertx.codegen.extra.sub.SomeType>() {
      public void handle(io.vertx.codegen.extra.sub.SomeType event) {
        handler.handle(io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)event));
      }
    });
    return this;
  }

  /**
   * Pause the <code>ReadStream</code>, it sets the buffer in <code>fetch</code> mode and clears the actual demand.
   * <p>
   * While it's paused, no data will be sent to the data <code>handler</code>.
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> pause() { 
    delegate.pause();
    return this;
  }

  /**
   * Resume reading, and sets the buffer in <code>flowing</code> mode.
   * <p/>
   * If the <code>ReadStream</code> has been paused, reading will recommence on it.
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> resume() { 
    delegate.resume();
    return this;
  }

  /**
   * Fetch the specified <code>amount</code> of elements. If the <code>ReadStream</code> has been paused, reading will
   * recommence with the specified <code>amount</code> of items, otherwise the specified <code>amount</code> will
   * be added to the current stream demand.
   * @param amount 
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> fetch(long amount) { 
    delegate.fetch(amount);
    return this;
  }

  /**
   * Set an end handler. Once the stream has ended, and there is no more data to be read, this handler will be called.
   * @param endHandler 
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.rxjava.core.streams.ReadStream<io.vertx.rxjava.codegen.extra.sub.SomeType> endHandler(Handler<Void> endHandler) { 
    delegate.endHandler(endHandler);
    return this;
  }

  /**
   * Pause this stream and return a  to transfer the elements of this stream to a destination .
   * <p/>
   * The stream will be resumed when the pipe will be wired to a <code>WriteStream</code>.
   * @return a pipe
   */
  public io.vertx.rxjava.core.streams.Pipe<io.vertx.rxjava.codegen.extra.sub.SomeType> pipe() { 
    io.vertx.rxjava.core.streams.Pipe<io.vertx.rxjava.codegen.extra.sub.SomeType> ret = io.vertx.rxjava.core.streams.Pipe.newInstance((io.vertx.core.streams.Pipe)delegate.pipe(), TYPE_ARG_6);
    return ret;
  }

  /**
   * Pipe this <code>ReadStream</code> to the <code>WriteStream</code>.
   * <p>
   * Elements emitted by this stream will be written to the write stream until this stream ends or fails.
   * <p>
   * Once this stream has ended or failed, the write stream will be ended and the <code>handler</code> will be
   * called with the result.
   * @param dst the destination write stream
   * @param handler 
   */
  public void pipeTo(io.vertx.rxjava.core.streams.WriteStream<io.vertx.rxjava.codegen.extra.sub.SomeType> dst, Handler<AsyncResult<Void>> handler) { 
    delegate.pipeTo(dst.getDelegate(), handler);
  }

  /**
   * Pipe this <code>ReadStream</code> to the <code>WriteStream</code>.
   * <p>
   * Elements emitted by this stream will be written to the write stream until this stream ends or fails.
   * <p>
   * Once this stream has ended or failed, the write stream will be ended and the <code>handler</code> will be
   * called with the result.
   * @param dst the destination write stream
   */
  public void pipeTo(io.vertx.rxjava.core.streams.WriteStream<io.vertx.rxjava.codegen.extra.sub.SomeType> dst) {
    pipeTo(dst, ar -> { });
  }

    /**
   * Pipe this <code>ReadStream</code> to the <code>WriteStream</code>.
   * <p>
   * Elements emitted by this stream will be written to the write stream until this stream ends or fails.
   * <p>
   * Once this stream has ended or failed, the write stream will be ended and the <code>handler</code> will be
   * called with the result.
   * @param dst the destination write stream
   * @return 
   */
  public Single<Void> rxPipeTo(io.vertx.rxjava.core.streams.WriteStream<io.vertx.rxjava.codegen.extra.sub.SomeType> dst) { 
    return Single.create(new SingleOnSubscribeAdapter<>(fut -> {
      pipeTo(dst, fut);
    }));
  }

  public io.vertx.rxjava.codegen.extra.sub.SomeType foo(io.vertx.rxjava.codegen.extra.sub.SomeType arg) { 
    if (cached_0 != null) {
      return cached_0;
    }
    io.vertx.rxjava.codegen.extra.sub.SomeType ret = io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)delegate.foo(arg.getDelegate()));
    cached_0 = ret;
    return ret;
  }

  public void function(Function<io.vertx.rxjava.codegen.extra.sub.SomeType, io.vertx.rxjava.codegen.extra.sub.SomeType> function) { 
    delegate.function(new Function<io.vertx.codegen.extra.sub.SomeType,io.vertx.codegen.extra.sub.SomeType>() {
      public io.vertx.codegen.extra.sub.SomeType apply(io.vertx.codegen.extra.sub.SomeType arg) {
        io.vertx.rxjava.codegen.extra.sub.SomeType ret = function.apply(io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)arg));
        return ret.getDelegate();
      }
    });
  }

  public void asyncResult(Handler<AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType>> handler) { 
    delegate.asyncResult(new Handler<AsyncResult<io.vertx.codegen.extra.sub.SomeType>>() {
      public void handle(AsyncResult<io.vertx.codegen.extra.sub.SomeType> ar) {
        if (ar.succeeded()) {
          handler.handle(io.vertx.core.Future.succeededFuture(io.vertx.rxjava.codegen.extra.sub.SomeType.newInstance((io.vertx.codegen.extra.sub.SomeType)ar.result())));
        } else {
          handler.handle(io.vertx.core.Future.failedFuture(ar.cause()));
        }
      }
    });
  }

  public void asyncResult() {
    asyncResult(ar -> { });
  }

    public Single<io.vertx.rxjava.codegen.extra.sub.SomeType> rxAsyncResult() { 
    return Single.create(new SingleOnSubscribeAdapter<>(fut -> {
      asyncResult(fut);
    }));
  }

  public Handler<io.vertx.rxjava.codegen.extra.sub.SomeType> returnHandler() { 
    Handler<io.vertx.rxjava.codegen.extra.sub.SomeType> ret = new Handler<io.vertx.rxjava.codegen.extra.sub.SomeType>() {
      public void handle(io.vertx.rxjava.codegen.extra.sub.SomeType event) {
          delegate.returnHandler().handle(event.getDelegate());
      }
    };
    return ret;
  }

  public Handler<AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType>> returnHandlerAsyncResult() { 
    Handler<AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType>> ret = new Handler<AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType>>() {
      public void handle(AsyncResult<io.vertx.rxjava.codegen.extra.sub.SomeType> ar) {
        if (ar.succeeded()) {
          delegate.returnHandlerAsyncResult().handle(io.vertx.core.Future.succeededFuture(ar.result().getDelegate()));
        } else {
          delegate.returnHandlerAsyncResult().handle(io.vertx.core.Future.failedFuture(ar.cause()));
        }
      }
    };
    return ret;
  }

  private io.vertx.rxjava.codegen.extra.sub.SomeType cached_0;
  public static UseVertxGenDeclarationsFromAnotherPackage newInstance(io.vertx.codegen.extra.UseVertxGenDeclarationsFromAnotherPackage arg) {
    return arg != null ? new UseVertxGenDeclarationsFromAnotherPackage(arg) : null;
  }

}
